{-# LANGUAGE Safe #-}

-- | Strict versions of some standard Haskell types.
module Data.Strict (
    module Data.Strict.Classes
  , module Data.Strict.These
  , module Data.Strict.Tuple
  , module Data.Strict.Maybe
  , module Data.Strict.Either
) where

import Data.Strict.Classes
import Data.Strict.These
import Data.Strict.Tuple
import Data.Strict.Maybe
import Data.Strict.Either
